@@ -7,11 +7,14 @@ use File::Spec;
 use File::Slurp;
 use Pod::Simple::Search;
 use JSON::XS;
+use Path::Class::File;
 use Pod::POM;
 use XML::Simple;
 use LWP::Simple;
 use List::MoreUtils qw(uniq);
 
+our $VERSION = 0.02007;
+
 
 
 use lib(qw(/Users/mo/Documents/workspace/Catalyst-Controller-POD/lib));
@@ -19,96 +22,27 @@ use Catalyst::Controller::POD::Template;
 
 use base "Catalyst::Controller::POD::Search";
 
-__PACKAGE__->mk_accessors(qw(_dist_dir inc namespaces self dir));
+__PACKAGE__->mk_accessors(qw(_dist_dir inc namespaces self dir show_home_tab initial_module home_tab_content expanded_module_tree));
 
 __PACKAGE__->config(
- self => 1,
- namespaces => ["*"]
+ self                 => 1,
+ namespaces           => ["*"],
+ initial_module       => "",
+ show_home_tab        => 1,
+ expanded_module_tree => 0,
+ home_tab_content     => <<HTML,
+<div style="width:500px; margin:50px" class='x-box-blue' id='move-me'>
+<div class="x-box-tl"><div class="x-box-tr"><div class="x-box-tc"></div></div></div>
+<div class="x-box-ml"><div class="x-box-mr"><div class="x-box-mc">
+<h3 style="margin-bottom:5px;">Search the CPAN</h3>
+<input type="text" name="search" id="search" class="x-form-text" style='font-size: 20px; height: 31px'/>
+<div style="padding-top:4px;">Type at least three characters</div>
+</div></div></div>
+<div class="x-box-bl"><div class="x-box-br"><div class="x-box-bc"></div></div></div>
+</div>
+HTML
 );
 
-
-=head1 NAME
-
-Catalyst::Controller::POD - Serves PODs right from your Catalyst application
-
-=head1 VERSION
-
-Version 0.02
-
-=cut
-our $VERSION = '0.02006';
-
-=head1 SYNOPSIS
-
-Create a new controller and paste this code:
-
-  package MyApp::Controller::YourNewController;  # <-- Change this to your controller
-  
-  use strict;
-  use warnings;
-  use base 'Catalyst::Controller::POD';
-  __PACKAGE__->config(
-    inc        => 1,
-    namespaces => [qw(Catalyst::Manual*)],
-    self       => 1,
-    dirs       => [qw()]
-  );
-  1;
-
-=head1 DESCRIPTION
-
-This is a catalyst controller which serves PODs. It allows you to browse through your local
-repository of modules. On the front page of this controller is a search box
-which uses CPAN's xml interface to retrieve the results. If you click on one of them
-the POD is displayed in this application.
-
-Cross links in PODs are resolved and pop up as a new tab. If the module you clicked on is
-not installed this controller fetches the source code from CPAN and creates the pod locally.
-There is also a TOC which is always visible and scrolls the current POD to the selected section.
-
-It is written using a JavaScript framework called ExtJS (L<http://www.extjs.com>) which
-generate beautiful and intuitive interfaces.
-
-Have a look at L<http://cpan.org/authors/id/P/PE/PERLER/pod-images/pod-encyclopedia-01.png>
-
-=head1 CONFIGURATION
-
-=over
-
-=item inc (Boolean)
-
-Search for modules in @INC. Set it to 1 or 0.
-
-Defaults to C<0>.
-
-=item namespaces (Arrayref)
-
-Filter by namespaces. See L<Pod::Simple::Search> C<limit_glob> for syntax.
-
-Defaults to C<["*"]>
-
-=item self (Boolean)
-
-Search for modules in C<< $c->path_to( 'lib' ) >>.
-
-Defaults to C<1>.
-
-=item dirs (Arrayref)
-
-Search for modules in these directories.
-
-Defaults to C<[]>.
-
-=head1 NOTICE
-
-This module works fine for most PODs but there are a few which do not get rendered properly. 
-Please report any bug you find. See L</BUGS>.
-
-Have a look at L<Pod::Browser> which is a catalyst application running this controller. You
-can use it as a stand-alone POD server.
-
-=cut
-
 sub search : Local {
 	my ( $self, $c ) = @_;
 	my $k = $c->req->param("value");
@@ -277,21 +211,18 @@ sub _root {
 }
 
 sub new {
-	my $self = shift;
-	my $new  = $self->next::method(@_);
-	my $path;
-	eval { $path = dist_file( 'Catalyst-Controller-POD', 'docs.js' ); };
-	if ($@) {
-		# I'm on my local machine
-		$path = "/Users/mo/Documents/workspace/Catalyst-Controller-POD/share";
-	} else {
-		my ( $volume, $dirs, $file ) = File::Spec->splitpath($path);
-		$path = File::Spec->catfile( $volume, $dirs );
-	}
-	$new->_dist_dir($path);
-	return $new;
+    my $class = shift;
+    my $self  = $class->next::method(@_);
+    my $file  = Path::Class::File->new( 'share', 'dist.js' );
+    eval {
+        $file = Path::Class::File->new(
+            dist_file( 'Catalyst-Controller-POD', 'docs.js' ) );
+    } unless(-e $file);
+    $self->_dist_dir( $file->dir );
+    return $self;
 }
 
+
 sub index : Path : Args(0) {
 	my ( $self, $c ) = @_;
 	$c->res->content_type('text/html; charset=utf-8');
@@ -302,6 +233,11 @@ sub index : Path : Args(0) {
 	);
 }
 
+sub get_home_tab_content : Path("home_tab_content") {
+	my ( $self, $c ) = @_;
+	$c->response->body($self->home_tab_content);
+}
+
 sub static : Path("static") {
 	my ( $self, $c, @file ) = @_;
 	my $file = File::Spec->catfile(@file);
@@ -312,20 +248,135 @@ sub static : Path("static") {
 		$c->res->content_type('text/html; charset=utf-8');
 	} else {
 		if ( $file eq "docs.js" ) {
-			my $root = $self->_root($c);
-			$data =~ s/\[% root %\]/$root/g;
+			_replace_template_vars(\$data, "root",                       $self->_root($c));
+			_replace_template_vars(\$data, "initial_module",             $self->initial_module);
+			_replace_template_vars(\$data, "show_home_tab",              $self->show_home_tab ? "true" : "false");
+			_replace_template_vars(\$data, "expand_module_tree_on_load", $self->expanded_module_tree ? "true" : "false");
 		}
 		$c->response->body($data);
 	}
 }
 
+# A poor man's template module. 
+sub _replace_template_vars {
+	my ($data_ref, $var_name, $var_val) = @_;
+	$$data_ref =~ s/\[% $var_name %\]/$var_val/g;
+}
+
+1;
+
+__END__
+
+=head1 NAME
+
+Catalyst::Controller::POD - Serves PODs right from your Catalyst application
+
+=head1 SYNOPSIS
+
+Create a new controller and paste this code:
+
+  package MyApp::Controller::YourNewController;  # <-- Change this to your controller
+  
+  use strict;
+  use warnings;
+  use base 'Catalyst::Controller::POD';
+  __PACKAGE__->config(
+    inc        => 1,
+    namespaces => [qw(Catalyst::Manual*)],
+    self       => 1,
+    dirs       => [qw()]
+  );
+  1;
+
+=head1 DESCRIPTION
+
+This is a catalyst controller which serves PODs. It allows you to browse through your local
+repository of modules. On the front page of this controller is a search box
+which uses CPAN's xml interface to retrieve the results. If you click on one of them
+the POD is displayed in this application.
+
+Cross links in PODs are resolved and pop up as a new tab. If the module you clicked on is
+not installed this controller fetches the source code from CPAN and creates the pod locally.
+There is also a TOC which is always visible and scrolls the current POD to the selected section.
+
+It is written using a JavaScript framework called ExtJS (L<http://www.extjs.com>) which
+generate beautiful and intuitive interfaces.
+
+Have a look at L<http://cpan.org/authors/id/P/PE/PERLER/pod-images/pod-encyclopedia-01.png>
+
+=head1 CONFIGURATION
+
+=over
+
+=item dirs (Arrayref)
+
+Search for modules in these directories.
+
+Defaults to C<[]>.
+
+=item expanded_module_tree (Boolean)
+
+Expand the module browser tree on initial page load.
+
+Defaults to C<1>
+
+=item home_tab_content (String)
+
+HTML to be displayed in the Home tab.
+
+Defaults to the existing CPAN search box.
+
+=item inc (Boolean)
+
+Search for modules in @INC. Set it to 1 or 0.
+
+Defaults to C<0>.
+
+=item initial_module (String)
+
+If this option is specified, a tab displaying the perldoc for the given module
+will be opened on load.  Handy if you wish to disable the home tab and specify
+a specific module's perldoc as the initial page a user sees.
+
+Defaults to C<"">
+
+=item namespaces (Arrayref)
+
+Filter by namespaces. See L<Pod::Simple::Search> C<limit_glob> for syntax.
+
+Defaults to C<["*"]>
+
+=item self (Boolean)
+
+Search for modules in C<< $c->path_to( 'lib' ) >>.
+
+Defaults to C<1>.
+
+=item show_home_tab (Boolean)
+
+Show or hide the home tab.
+
+Defaults to C<1>
+
+=head1 NOTICE
+
+This module works fine for most PODs but there are a few which do not get rendered properly. 
+Please report any bug you find. See L</BUGS>.
+
+Have a look at L<Pod::Browser> which is a catalyst application running this controller. You
+can use it as a stand-alone POD server.
+
 =head1 TODO
 
 Write more tests!
 
 =head1 AUTHOR
 
-Moritz Onken <onken@houseofdesign.de>
+Moritz Onken <onken@netcubed.de>
+
+=head1 CONTRIBUTORS
+
+Tristan Pratt
 
 =head1 BUGS
 
@@ -377,5 +428,4 @@ This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
 
-=cut
-1;    # End of Catalyst::Controller::POD
+=cut
\ No newline at end of file
